@@ -1,9 +1,16 @@
 from .Data import Data
+
+import base64
+import ipaddress
+import random
+import struct
+from random import randint
+from telethon.sessions.string import (_STRUCT_PREFORMAT, CURRENT_VERSION,
+                                          StringSession)
 from pyrogram import Client, filters
 from pyrogram1 import Client as Client1
 from telethon.sync import TelegramClient
 from asyncio.exceptions import TimeoutError
-from telethon.sessions import StringSession
 from pyrogram.types import Message, InlineKeyboardButton, InlineKeyboardMarkup
 from telethon.tl.functions.channels import (
     JoinChannelRequest, LeaveChannelRequest)
@@ -25,10 +32,12 @@ ERROR_MESSAGE = "{}\n\nSomething Error in Session Generator Bot\nReport it To @L
 
 
 async def generate_session(
-    bot: Client, msg: Message, telethon=False, old_pyro: bool = False
+    bot: Client, msg: Message, telethon=False, hellbot=False, old_pyro: bool = False
 ):
     if telethon:
         ty = "Telethon"
+    elif hellbot:
+        ty = "HellBot"
     else:
         ty = "Pyrogram"
         if not old_pyro:
@@ -173,24 +182,90 @@ async def generate_session(
             pass
     else:
         string_session = await client.export_session_string()
-        try:
+        if hellbot:
+            hell_session = hellbot_session(string_session)
             await client.send_message(
                 "me",
                 "**{} ~ STRING SESSION** \n\n`{}` \n\n• __Dont Share String Session With Anyone__\n• __Dont Invite Anyone To Heroku__".format(
-                    "TELETHON" if telethon else "PYROGRAM", string_session
+                    "Hell Bot", hell_session
                 ),
             )
-        except KeyError:
-            pass
+        else:
+            await client.send_message(
+                "me",
+                "**{} ~ STRING SESSION** \n\n`{}` \n\n• __Dont Share String Session With Anyone__\n• __Dont Invite Anyone To Heroku__".format(
+                    "Pyrogram", string_session
+                ),
+            )
+    try:
+        await client.join_chat("@LegendBot_OP")
+    except BaseException:
+        pass
     await client.disconnect()
     await phone_code_msg.reply(
-        "Successfully String  Session Has Been Generated {} \n\nPlease check your saved messages!".format(
-            "TELETHON" if telethon else "PYROGRAM"
+        "Successfully String  Session Has Been Generated \n\nPlease check your saved messages!"
         ),
         reply_markup=InlineKeyboardMarkup(Data.support_button),
     )
 
 
+
+def helltopi(text):
+    res = ''.join(
+        map(
+            random.choice,
+            zip(text.lower(), text.upper()),
+        )
+    )
+    return res.strip()
+
+
+def hellbot_session(session):
+    pyro_format = {
+        351: ">B?256sI?",
+        356: ">B?256sQ?",
+        362: ">BI?256sQ?",
+    }
+
+    ipv4_dc = {
+        1: "149.154.175.53",
+        2: "149.154.167.51",
+        3: "149.154.175.100",
+        4: "149.154.167.91",
+        5: "91.108.56.130",
+    }
+
+    error_msg = "Error in generating session! Report it in Comments of @TeamLegendBots"
+
+    # converting pyrogram session
+    if len(session) in pyro_format.keys():
+        if len(session) in [351, 356]:
+            dc_id, _, auth_key, _, _ = struct.unpack(
+                pyro_format[len(session)],
+                base64.urlsafe_b64decode(session + "=" * (-len(session) % 4)),
+            )
+        else:
+            dc_id, _, _, auth_key, _, _ = struct.unpack(
+                pyro_format[len(session)],
+                base64.urlsafe_b64decode(session + "=" * (-len(session) % 4)),
+            )
+
+        # https://github.com/HellBoy-OP/Telethon/blob/v1/telethon/sessions/string.py
+        new_session = CURRENT_VERSION + StringSession.encode(
+            struct.pack(
+                _STRUCT_PREFORMAT.format(4),
+                dc_id,
+                ipaddress.ip_address(ipv4_dc[dc_id]).packed,
+                443,
+                auth_key
+            )
+        )
+        return f"=={helltopi('hell')}{new_session}{helltopi('bot')}=="
+    else:
+        return error_msg
+
+
+
 async def cancelled(msg):
     if "/cancel" in msg.text:
         await msg.reply(
